/******************************************************************************
* To the extent possible under law, Sebastian Roith
* <https://www.roith-unterrichtet.de> has waived all copyright and related or
* neighboring rights to this script. This work is published from Germany.
******************************************************************************/

/**
* Erstellt URL einer Vektorgrafik eines Transportroboters mit den vorgegebenen Eigenschaften
* @return String    URL der Vektorgrafik
*/
function createrobotimg(
    farbe,      // Rahmenfarbe, erlaubt ist rot, grün, blau und grau
    achsen,     // Anzahl an Achsen (0-5)
    hoehe       // Anzahl an gestapelten Rahmenelementen (min. 1)
) {
    achsen = +achsen;
    hoehe = Math.max(1, +hoehe);
    var xheight = -825.690 + Math.max(0, hoehe) * 178 - 177.931;
    var svg = '<?xml version="1.0" encoding="UTF-8"?>\n' +
'<svg width="2145.4" height="' + (1671.1 + xheight) + '" version="1.1" viewBox="0 0 2145.4 ' + (1671.1 + xheight) + '" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">\n' +
'	<defs>\n' +
'		<linearGradient id="g"><stop style="stop-color:#888a85" offset="0"/><stop style="stop-color:#d3d7cf" offset="1"/>\n' +
'		</linearGradient>\n' +
'		<linearGradient id="c"><stop style="stop-color:#888a85" offset="0"/><stop style="stop-color:#2e3436" offset="1"/>\n' +
'		</linearGradient>\n' +
'		<filter id="an" color-interpolation-filters="sRGB"><feGaussianBlur stdDeviation="0.84902129"/>\n' +
'		</filter>\n' +
'		<filter id="ap" x="-.27454" y="-.8224" width="1.5491" height="2.6448" color-interpolation-filters="sRGB"><feGaussianBlur stdDeviation="7.6370113"/>\n' +
'		</filter>\n' +
'		<filter id="ao" x="-.21598" y="-.57614" width="1.432" height="2.1523" color-interpolation-filters="sRGB"><feGaussianBlur stdDeviation="7.4942451"/>\n' +
'		</filter>\n' +
'		<filter id="aq" x="-.15667" y="-.51062" width="1.3133" height="2.0212" color-interpolation-filters="sRGB"><feGaussianBlur stdDeviation="8.9803205"/>\n' +
'		</filter>\n' +
'		<linearGradient id="ag" x1="373.54" x2="369.93" y1="801.85" y2="451.33" gradientTransform="matrix(.85106 0 0 .85364 -73.862 -277.01)" gradientUnits="userSpaceOnUse"><stop offset="0"/><stop style="stop-color:#2f2f2f" offset=".79022"/><stop offset="1"/>\n' +
'		</linearGradient>\n' +
'		<linearGradient id="af" x1="449.56" x2="377.48" y1="749.06" y2="679.34" gradientTransform="matrix(.53986 0 0 .85106 116.35 -306.58)" gradientUnits="userSpaceOnUse"><stop style="stop-color:#898989" offset="0"/><stop style="stop-color:#525252" offset="1"/>\n' +
'		</linearGradient>\n' +
'		<radialGradient id="z" cx="381.56" cy="623.56" r="191.44" gradientTransform="matrix(.56704 -.005106 .019585 .90023 88.093 -304.95)" gradientUnits="userSpaceOnUse"><stop offset="0"/><stop style="stop-color:#2a2a2a" offset=".75807"/><stop offset="1"/>\n' +
'		</radialGradient>\n' +
'		<linearGradient id="ae" x1="-563.5" x2="-421.67" y1="482.04" y2="482.04" gradientTransform="translate(722.94,-224.27)" gradientUnits="userSpaceOnUse"><stop style="stop-color:#8e8e8e" offset="0"/><stop style="stop-color:#d4d4d4" offset="1"/>\n' +
'		</linearGradient>\n' +
'		<radialGradient id="u" cx="-326.94" cy="264.33" r="10.499" gradientTransform="matrix(1 0 0 1.6318 0 -166.56)" gradientUnits="userSpaceOnUse"><stop style="stop-color:#555753" offset="0"/><stop style="stop-color:#2e3436" offset="1"/>\n' +
'		</radialGradient>\n' +
'		<linearGradient id="t" x1="68.947" x2="88.105" y1="224.6" y2="169.62" gradientTransform="translate(124.96,85.382)" gradientUnits="userSpaceOnUse" xlink:href="#b" spreadMethod="reflect"/>\n' +
'		<linearGradient id="b"><stop offset="0"/><stop style="stop-color:#fff" offset="1"/>\n' +
'		</linearGradient>\n' +
'		<radialGradient id="ab" cx="143.82" cy="180.28" r="62.215" fx="99.424" fy="155.6" gradientTransform="matrix(.1321 -1.36 .96225 .093467 -48.648 359.03)" gradientUnits="userSpaceOnUse" spreadMethod="reflect"><stop offset="0"/><stop style="stop-color:#323232" offset=".90166"/><stop style="stop-color:#bcbcbc" offset="1"/>\n' +
'		</radialGradient>\n' +
'		<linearGradient id="s" x1="84.507" x2="103.17" y1="237.87" y2="193.25" gradientUnits="userSpaceOnUse" xlink:href="#b" spreadMethod="reflect"/>\n' +
'		<linearGradient id="aj" x1="147.95" x2="239.49" y1="193.28" y2="193.28" gradientTransform="matrix(1.0252,0,0,1.0252,-4.8833,-4.8722)" gradientUnits="userSpaceOnUse"><stop style="stop-color:#6f6f6f" offset="0"/><stop offset="1"/>\n' +
'		</linearGradient>\n' +
'		<linearGradient id="d" x1="108" x2="195.19" y1="269.92" y2="87.849" gradientTransform="matrix(1.0574,0,0,1.0574,-6.6553,-10.25)" gradientUnits="userSpaceOnUse" xlink:href="#b"/>\n' +
'		<linearGradient id="e" x1="103.48" x2="106.64" y1="171.2" y2="164.71" gradientTransform="matrix(1.0574,0,0,1.0574,57.09,220.03)" gradientUnits="userSpaceOnUse" xlink:href="#b" spreadMethod="reflect"/>\n' +
'		<linearGradient id="r" x1="90.409" x2="195.19" y1="282.98" y2="87.849" gradientTransform="matrix(1.0574,0,0,1.0574,-20.171,-12.179)" gradientUnits="userSpaceOnUse" xlink:href="#b"/>\n' +
'		<linearGradient id="q" x1="90.409" x2="195.19" y1="282.98" y2="87.849" gradientTransform="matrix(.94458 0 0 .94458 27.88 18.996)" gradientUnits="userSpaceOnUse" xlink:href="#b"/>\n' +
'		<radialGradient id="aa" cx="162.18" cy="199.75" r="35.79" fx="141.03" fy="211.93" gradientTransform="matrix(1,0,0,1.3582,0,-68.414)" gradientUnits="userSpaceOnUse" spreadMethod="reflect"><stop style="stop-color:#fff" offset="0"/><stop style="stop-color:#11187b" offset="1"/>\n' +
'		</radialGradient>\n' +
'		<linearGradient id="ai" x1="163.2" x2="238.49" y1="267.13" y2="128.28" gradientTransform="matrix(.9865 0 0 .9865 2.6094 2.6138)" gradientUnits="userSpaceOnUse"><stop style="stop-color:#494949" offset="0"/><stop style="stop-color:#cdcdcd" offset="1"/>\n' +
'		</linearGradient>\n' +
'		<linearGradient id="ah" x1="128.66" x2="205.72" y1="262.9" y2="112.9" gradientTransform="matrix(.9865 0 0 .9865 2.6094 2.6138)" gradientUnits="userSpaceOnUse"><stop style="stop-color:#141734" offset="0"/><stop style="stop-color:#fff" offset="1"/>\n' +
'		</linearGradient>\n' +
'		<linearGradient id="p" x1="154.09" x2="233.74" y1="264.43" y2="125.2" gradientTransform="matrix(.9452 0 0 .9452 10.617 10.614)" gradientUnits="userSpaceOnUse" xlink:href="#f"/>\n' +
'		<linearGradient id="f"><stop style="stop-color:#838383" offset="0"/><stop offset="1"/>\n' +
'		</linearGradient>\n' +
'		<linearGradient id="o" x1="154.09" x2="233.74" y1="264.43" y2="125.2" gradientTransform="matrix(.90036 0 0 .90036 19.303 19.298)" gradientUnits="userSpaceOnUse" xlink:href="#f"/>\n' +
'		<linearGradient id="n" x1="154.09" x2="233.74" y1="264.43" y2="125.2" gradientTransform="matrix(.85552 0 0 .85552 27.99 27.982)" gradientUnits="userSpaceOnUse" xlink:href="#f"/>\n' +
'		<linearGradient id="m" x1="154.09" x2="233.74" y1="264.43" y2="125.2" gradientTransform="matrix(.81566 0 0 .81566 35.711 35.701)" gradientUnits="userSpaceOnUse" xlink:href="#f"/>\n' +
'		<radialGradient id="i" cx="143.82" cy="180.28" r="62.215" fx="99.424" fy="155.6" gradientTransform="matrix(.1321 -1.36 .96225 .093467 -48.648 359.03)" gradientUnits="userSpaceOnUse" xlink:href="#ab" spreadMethod="reflect"/>\n' +
'		<linearGradient id="l" x1="147.95" x2="239.49" y1="193.28" y2="193.28" gradientTransform="matrix(1.0252,0,0,1.0252,-4.8833,-4.8722)" gradientUnits="userSpaceOnUse" xlink:href="#aj"/>\n' +
'		<radialGradient id="h" cx="162.18" cy="199.75" r="35.79" fx="141.03" fy="211.93" gradientTransform="matrix(1,0,0,1.3582,0,-68.414)" gradientUnits="userSpaceOnUse" xlink:href="#aa" spreadMethod="reflect"/>\n' +
'		<linearGradient id="k" x1="163.2" x2="238.49" y1="267.13" y2="128.28" gradientTransform="matrix(.9865 0 0 .9865 2.6094 2.6138)" gradientUnits="userSpaceOnUse" xlink:href="#ai"/>\n' +
'		<linearGradient id="j" x1="128.66" x2="205.72" y1="262.9" y2="112.9" gradientTransform="matrix(.9865 0 0 .9865 2.6094 2.6138)" gradientUnits="userSpaceOnUse" xlink:href="#ah"/>\n' +
'		<linearGradient id="ad" x1="1189.6" x2="1484.3" y1="644.03" y2="591.13" gradientTransform="translate(12.652 823)" gradientUnits="userSpaceOnUse" spreadMethod="reflect"><stop offset="0" style="stop-color:#888a85"/><stop style="stop-color:#555753" offset="1"/>\n' +
'		</linearGradient>\n' +
'		<radialGradient id="y" cx="-336.42" cy="272.31" r="51.941" gradientTransform="matrix(1 0 0 1.6318 0 -166.56)" gradientUnits="userSpaceOnUse"><stop style="stop-color:#888a85" offset="0"/><stop style="stop-color:#d3d7cf" offset="1"/>\n' +
'		</radialGradient>\n' +
'		<radialGradient id="x" cx="540.97" cy="732.94" r="111.36" gradientTransform="matrix(1 0 0 .66106 12 361.12)" gradientUnits="userSpaceOnUse" xlink:href="#c"/>\n' +
'		<radialGradient id="v" cx="359.21" cy="420.11" r="111.36" gradientTransform="matrix(.65767 0 0 .57652 518.02 437.67)" gradientUnits="userSpaceOnUse" xlink:href="#c"/>\n' +
'		<radialGradient id="w" cx="359.21" cy="420.11" r="111.36" gradientTransform="matrix(1 0 0 .87661 94.929 -289.85)" gradientUnits="userSpaceOnUse" xlink:href="#c"/>\n' +
'		<radialGradient id="ac" cx="359.21" cy="420.11" r="111.36" gradientTransform="matrix(.81074 0 0 .7107 541.99 51.081)" gradientUnits="userSpaceOnUse" xlink:href="#c"/>\n' +
'		<linearGradient id="am" x1="407.96" x2="529.77" y1="394.38" y2="377.75" gradientTransform="translate(12 113.69)" gradientUnits="userSpaceOnUse" xlink:href="#g"/>\n' +
'		<linearGradient id="al" x1="-259.09" x2="-350.53" y1="544.8" y2="546.96" gradientTransform="translate(80.847 80.827)" gradientUnits="userSpaceOnUse" xlink:href="#g"/>\n' +
'		<linearGradient id="ak" x1="-799.7" x2="-880.43" y1="269.28" y2="266.86" gradientTransform="translate(-35.774 108.58)" gradientUnits="userSpaceOnUse" xlink:href="#g"/>\n' +
'		<g id="a" transform="matrix(-.99389 .11034 .11034 .99389 -246.59 1019.6)"><path d="m225.3 97.468c-57.076 0-103.35 73.18-103.35 163.43 0 90.249 46.274 163.4 103.35 163.4 0.28544 0 0.5662-0.0231 0.85105-0.0265 0.16017-2e-3 0.31881 3e-3 0.47872 0h89.786v-75.292c-1.6935-0.0331-3.3641-0.19-5.0266-0.50531-1.6711-0.31696-3.3423-0.7972-4.9733-1.383-1.631-0.58577-3.2315-1.2894-4.8138-2.1276-1.5822-0.8382-3.1295-1.7981-4.6542-2.8723s-3.0362-2.2699-4.4947-3.5638c-1.4584-1.2939-2.8719-2.6783-4.2553-4.1755s-2.7162-3.1031-4.0159-4.7872c-1.2996-1.6841-2.5693-3.4644-3.7766-5.3191-1.2072-1.8547-2.3514-3.789-3.4574-5.7978s-2.1687-4.0768-3.1649-6.2233c-0.99616-2.1466-1.9415-4.3543-2.8191-6.6223-0.87753-2.268-1.6966-4.595-2.4468-6.968s-1.4337-4.7989-2.0478-7.2606c-0.61413-2.4616-1.153-4.966-1.6224-7.4999-0.46936-2.5339-0.85429-5.0963-1.1702-7.6861-0.31583-2.5898-0.56442-5.2164-0.71804-7.8457-0.21327-3.041-0.31191-6.0789-0.29259-9.0956 0.0196-3.0168 0.16025-5.992 0.39897-8.9627 0.23873-2.9707 0.59217-5.9269 1.0372-8.8297 0.4451-2.9028 0.98424-5.7508 1.6224-8.5637 0.63812-2.813 1.3628-5.5965 2.1808-8.2978 0.81803-2.7013 1.7279-5.3311 2.7127-7.8988 0.98484-2.5678 2.053-5.061 3.1914-7.4733 1.1385-2.4124 2.3381-4.7329 3.617-6.968s2.6364-4.4001 4.0425-6.4361 2.8681-3.9562 4.3882-5.7712c1.5202-1.815 3.0863-3.5076 4.7074-5.0797 1.6212-1.5721 3.291-3.0277 5-4.3351 1.7089-1.3074 3.4558-2.4632 5.2393-3.484 1.7836-1.0208 3.6071-1.8941 5.4521-2.6064s3.7184-1.267 5.6116-1.6489c1.4989-0.30238 3.0262-0.42225 4.5479-0.50532v-74.92h-90.265v0.02655c-0.28485-0.0034-0.56561-0.02655-0.85105-0.02655z" style="fill:url(#ag)"/><path d="m319.2 165.95c-12.566 0-24.233 6.1495-33.829 16.649-12.607 17.803-26.049 45.69-26.049 76.458 0 35.243 10.774 55.144 18.177 67.131 10.723 16.682 25.446 26.994 41.702 26.994 32.797 0 59.361-41.913 59.361-93.616s-26.564-93.616-59.361-93.616z" style="fill:url(#af);stroke-width:1.7021;stroke:#b3b3b3"/><path transform="matrix(.85106 0 -.34565 .7777 -68.904 -274.99)" d="m483.83 538.8 103.03 1.1725c-2.2304 13.256-2.2698 27.332-2.2619 41.59l-104.85-0.39083c0.417-15.512-0.2933-34.477 4.0873-42.371z" style="fill-opacity:.25333;fill:#fff;filter:url(#aq)"/><path transform="matrix(1.2145 -.40985 -.48591 .86532 -416.51 -119.43)" d="m973.14 939.46 55.995 20.742c1.8637 8.8035 2.722 15.227 3.3542 24.817l-60.831-23.675c2.8957-5.7263 1.7868-13.421 1.4825-21.885z" style="fill-opacity:.41778;fill:#ececec;filter:url(#ao)"/><path transform="matrix(.88447 -.19645 -.083258 .50296 -467.08 -14.132)" d="m1036.5 964.37c-0.1037 5.1395 0.9686 15.695 0.2493 21.469l-60.171-8.4699c0.61239-6.8694 1.3913-17.987 1.56-17.802 0 0 49.351 4.7757 58.362 4.8026z" style="fill-opacity:.42667;fill:#ececec;filter:url(#ap)"/><path d="m318.94 97.503c-57.076 0-103.35 73.166-103.35 163.41 0 90.245 46.274 163.41 103.35 163.41s103.35-73.166 103.35-163.41c0-90.245-46.274-163.41-103.35-163.41zm0.57361 74.636c9.4858 0.15422 18.774 4.5476 26.943 12.004 21.983 17.84 32.738 61.383 26.808 98.777-5.592 39.969-31.329 68.215-56.821 66.501-27.24-0.50983-51.022-38.684-53.48-80.878-3.4124-48.801 23.791-95.899 54.644-96.376 0.63378-0.0278 1.274-0.037 1.9064-0.0267z" style="fill:url(#z);stroke-width:1.0015"/><path transform="matrix(.85106 0 0 .85106 122.72 41.265)" d="m231.22 153.88c-0.743-0.0121-1.4741-1e-3 -2.2188 0.0312-36.253 0.55928-68.228 55.735-64.219 112.91 2.888 49.431 30.836 94.153 62.844 94.75 29.953 2.0086 60.179-31.083 66.75-77.906 6.9678-43.808-5.6693-94.819-31.5-115.72-9.5985-8.735-20.51-13.882-31.656-14.062z" style="fill:none;filter:url(#an);stroke-linecap:round;stroke-width:10;stroke:url(#ae)"/><ellipse transform="scale(-1,1)" cx="-325.15" cy="263.61" rx="51.441" ry="84.26" style="fill:url(#y);stop-color:#000000;stroke:#555753"/><ellipse transform="scale(-1,1)" cx="-325.15" cy="263.61" rx="9.999" ry="16.633" style="fill:url(#u);stop-color:#000000;stroke:#555753"/>\n' +
'        <radialGradient id="radialGradient4883" cx="1491.3" cy="1098.86" r="41.844" gradientTransform="matrix(1 0 0 1.2914 0 -134.96)" gradientUnits="userSpaceOnUse"><stop style="stop-color:#555753" offset="0"/><stop style="stop-color:#888a85" offset="1"/></radialGradient>' +
'		</g>\n' +
'	</defs>\n';
    // Verschiebung nach oben/unten
    svg += '<g transform="translate(0,' + (xheight) + ')">';

    // Linke Räder
    if (achsen > 2)
        svg += '	<use id="rad-l1" transform="translate(1655.5 -279.2)" width="100%" height="100%" xlink:href="#a"/>\n';
    if ([0, 1, 3].indexOf(+achsen) == -1)
        svg += '	<use id="rad-l2" transform="translate(1862.3 -212.41)" width="100%" height="100%" xlink:href="#a"/>\n';
    if (achsen % 2)
        svg += '	<use id="rad-l3" transform="translate(2069.2 -145.62)" width="100%" height="100%" xlink:href="#a"/>\n';
    if ([0, 1, 3].indexOf(achsen) == -1)
        svg += '	<use id="rad-l4" transform="translate(2276 -78.831)" width="100%" height="100%" xlink:href="#a"/>\n';
    if (achsen > 2)
        svg += '	<use id="rad-l5" transform="translate(2482.8 -12.04)" width="100%" height="100%" xlink:href="#a"/>\n';
    svg += '	<path id="boden" d="m1970.2 1287.9-17.992 69.022-917.92 171.72-873.98-280.45-19.266-62 871.47 281.71z" style="fill:url(#ad);font-variation-settings:normal;stop-color:#000000;stroke-miterlimit:10;stroke-width:5;stroke:#000"/>\n' +
'	<path id="bodenstrebe" d="m1034.3 1528.6-32.936-62.711" style="fill:none;font-variation-settings:normal;stop-color:#000000;stroke-miterlimit:10;stroke:#000"/>\n' +
'	<path id="innen" d="m1094.9 1025 447.97 144.81-529.2 99.468-447.97-144.81z" style="fill:#d3d7cf;font-variation-settings:normal;stop-color:#000000;stroke-miterlimit:10;stroke-width:5;stroke:#000"/>\n';

    // Rahmenelemente
    for (var n = 0; n < Math.max(0, hoehe); ++n)
        svg += '	<g transform="translate(0,' + (-178 * n) + ')">\n' +
'		<path d="m1012.5 1289.9 957.7-180.01v178l-957.7 180.01z" style="fill:#204a87;font-variation-settings:normal;stop-color:#000000;stroke-linejoin:bevel;stroke-miterlimit:10;stroke-width:5;stroke:#000"/>\n' +
'		<path d="m141.03 1008.2v178l871.47 281.71v-178z" style="fill:#3465a4;font-variation-settings:normal;stop-color:#000000;stroke-linejoin:bevel;stroke-miterlimit:10;stroke-width:5;stroke:#000"/>\n' +
'		<path d="m1094.9 846.99v178l-529.2 99.468-348.19-112.55z" style="fill:#888a85;font-variation-settings:normal;stop-color:#000000;stroke-miterlimit:10;stroke-width:5;stroke:#000"/>\n' +
'		<path d="m1891 1104.4-796.16-257.36v178l447.97 144.81z" style="fill:#babdb6;font-variation-settings:normal;stop-color:#000000;stroke-miterlimit:10;stroke-width:5;stroke:#000"/>\n' +
'		<path d="m1098.7 828.15-957.7 180.01 871.47 281.71 957.7-180.01zm-3.8672 18.842 796.17 257.37-877.39 164.91-796.16-257.36z" style="fill:#729fcf;font-variation-settings:normal;stop-color:#000000;stroke-linejoin:bevel;stroke-miterlimit:10;stroke-width:5;stroke:#000"/>\n' +
'	</g>\n';
    svg += '	<path d="m1452 1251.44v89l78.687-14.151v-89z" style="fill:url(#radialGradient4883);font-variation-settings:normal;stop-color:#000000;stroke-linejoin:bevel;stroke-miterlimit:10;stroke-width:5;stroke:#000"/>\n'

    if (achsen > 2)
        svg += '	<use id="rad-r1" transform="translate(639.1 -72.926)" width="100%" height="100%" xlink:href="#a"/>\n';
    if ([0, 1, 3].indexOf(achsen) == -1)
        svg += '	<use id="rad-r2" transform="translate(845.92 -6.1349)" width="100%" height="100%" xlink:href="#a"/>\n';
    if (achsen % 2)
        svg += '	<use id="rad-r3" transform="translate(1052.7 60.656)" width="100%" height="100%" xlink:href="#a"/>\n';
    if ([0, 1, 3].indexOf(achsen) == -1)
        svg += '	<use id="rad-r4" transform="translate(1259.6 127.45)" width="100%" height="100%" xlink:href="#a"/>\n';
    if (achsen > 2)
        svg += '	<use id="rad-r5" transform="translate(1466.4 194.24)" width="100%" height="100%" xlink:href="#a"/>\n';

    farbe = createrobotimg.parseColor(farbe);
    if (farbe && (farbe != 'blau'))
        svg = svg.replace(new RegExp(createrobotimg.FARBEN['blau'][0], 'g'), createrobotimg.FARBEN[farbe][0]).replace(new RegExp(createrobotimg.FARBEN['blau'][1], 'g'), createrobotimg.FARBEN[farbe][1]).replace(new RegExp(createrobotimg.FARBEN['blau'][2], 'g'), createrobotimg.FARBEN[farbe][2]);

    svg += '</g></svg>';
    return window.URL.createObjectURL(new Blob([svg], {type: 'image/svg+xml'}));
}

// Farbpalette
createrobotimg.FARBEN = {
    'rot': ['#ef2929', '#c00', '#a40000'],
    'gruen': ['#8ae234', '#73d216', '#4e9a06'],
    'blau': ['#729fcf', '#3465a4', '#204a87'],
    'grau': ['#d3d7cf', '#babdb6', '#888a85']
};

// Erlaubte Farbwerte (menschenlesbar)
createrobotimg.FARBWERTE = 'rot, gruen, blau und grau';

// Erlaubte Farbwerte als Array
createrobotimg.ARR_FARBEN = ['rot', 'gruen', 'blau', 'grau'];

/**
* Prüft, ob color eine erlaubte Farbangabe ist, und liefert den kanonischen Farbname
* @return mixed     Kanonischer Farbname oder undefined
*/
createrobotimg.parseColor = function(
    color   // Farbangabe
) {
    var farbe = color.replace('ü', 'ue').replace('Ü', 'ue').replace('ß', 'ss').toLowerCase();
    return createrobotimg.FARBEN[farbe] ? farbe : undefined;
}
